package
Version:
v0.0.0-...-e8e64b1
Opens a new window with list of versions in this module.
Published: Mar 7, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package modcache provides support for fetching packages from a local Go module cache.
type Source struct {
FS fs.FS
}
Source fetches Go modules from a local Go module cache.
Files returns the module's files.
Module fetches a module from the module cache. If the module is in the
standard library, it is fetched from the local Go tree instead.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.